.. include:: ../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :hidden:

   applications/index
   changelog
   
-----

.. admonition:: Useful links
   :class: seealso

   - `Quick introduction to reStructuredText <https://docutils.sourceforge.io/docs/user/rst/quickref.html>`_
   - `Falco CLI documentation <https://falco.oluwatobi.dev/the_cli/start_project>`_
   - `Writing documentation <https://falco.oluwatobi.dev/guides/writing_documentation.html>`_
   - `Sphinx design <https://sphinx-design.readthedocs.io>`_
